@@ -14,7 +14,13 @@ except ModuleNotFoundError as e:
 
 
 class SpacyFactor(object):
-    def __init__(self, issue_type: str, simple_description: str, description: Optional[str] = None, debug=False):
+    def __init__(
+        self,
+        issue_type: str,
+        simple_description: str,
+        description: Optional[str] = None,
+        debug=False,
+    ):
         self.issue_type = issue_type
         self.simple_description = simple_description
         if description:
@@ -102,12 +108,31 @@ class SpacyFactor(object):
             spacy_span._.suggestions if spacy_span.has_extension("suggestions") else []
         )
 
-        learn_more = spacy_span._.learn_more if spacy_span.has_extension("learn_more") else ""
-        paragraph = spacy_span._.paragraph if spacy_span.has_extension("paragraph") else False
+        learn_more = (
+            spacy_span._.learn_more if spacy_span.has_extension("learn_more") else ""
+        )
+        paragraph = (
+            spacy_span._.paragraph if spacy_span.has_extension("paragraph") else False
+        )
         header = spacy_span._.header if spacy_span.has_extension("header") else ""
-        meta_dict = spacy_span._.meta_dict if spacy_span.has_extension("meta_dict") else {}
-        simple_description = spacy_span._.simple_description if spacy_span.has_extension("simple_description") else self.simple_description
-        accept_all_changes = spacy_span._.accept_all_changes if spacy_span.has_extension("accept_all_changes") else False
+        meta_dict = (
+            spacy_span._.meta_dict if spacy_span.has_extension("meta_dict") else {}
+        )
+        # SIMPLE DESCRIPTION IS DIFFERENT, since it is set when initialized
+        # so we need to check that the span doesn't just have an empty value
+        simple_description = (
+            spacy_span._.simple_description
+            if (
+                spacy_span.has_extension("simple_description")
+                and spacy_span._.simple_description != ""
+            )
+            else self.simple_description
+        )
+        accept_all_changes = (
+            spacy_span._.accept_all_changes
+            if spacy_span.has_extension("accept_all_changes")
+            else False
+        )
 
         if cased:
             suggestions = self.match_case(spacy_span, suggestions)
